@@ -21,11 +21,11 @@
 
 #include <Lum/Base/String.h>
 
-static StopWatch::Prefs *prefs=new StopWatch::Prefs();
-
 StopWatch::StopWatch()
  : clickAction(new Lum::Model::Action()),
-   alarmColor(1.0,0,0,Lum::OS::Display::textColor)
+   blinkTimer(new Lum::Model::Action()),
+   alarmColor(1.0,0,0,Lum::OS::Display::textColor),
+   showInvert(false)
 {
   if (Lum::OS::display->GetType()==Lum::OS::Display::typeTextual) {
     minFont=Lum::OS::display->GetFont(Lum::OS::Display::fontTypeProportional,
@@ -38,7 +38,12 @@ StopWatch::StopWatch()
     font=minFont;
   }
 
-  SetPrefs(::prefs);
+  AttachModel(blinkTimer);
+}
+
+StopWatch::~StopWatch()
+{
+  UnattachModel(blinkTimer);
 }
 
 Lum::Model::Action* StopWatch::GetClickAction() const
@@ -56,6 +61,7 @@ void StopWatch::SetAlarm(bool alarm)
 {
   if (this->alarm!=alarm) {
     this->alarm=alarm;
+    showInvert=false;
     Redraw();
   }
 }
@@ -160,9 +166,16 @@ void StopWatch::Draw(int x, int y, size_t w, size_t h)
 
   draw->PushFont(font,Lum::OS::Font::bold);
 
-  if (alarm) {
+  if (alarm && showInvert) {
     draw->PushForeground(alarmColor);
   }
+  else if (alarm) {
+    draw->PushForeground(alarmColor);
+    draw->FillRectangle(this->x,this->y,this->width,this->height);
+    draw->PopForeground();
+
+    draw->PushForeground(Lum::OS::Display::textColor);
+  }
   else {
     draw->PushForeground(Lum::OS::Display::textColor);
   }
@@ -175,6 +188,11 @@ void StopWatch::Draw(int x, int y, size_t w, size_t h)
 
   draw->PopForeground();
   draw->PopFont();
+
+  if (alarm) {
+    Lum::OS::display->RemoveTimer(blinkTimer);
+    Lum::OS::display->AddTimer(1,0,blinkTimer);
+  }
 }
 
 bool StopWatch::HandleMouseEvent(const Lum::OS::MouseEvent& event)
@@ -189,3 +207,13 @@ bool StopWatch::HandleMouseEvent(const Lum::OS::MouseEvent& event)
   return false;
 }
 
+void StopWatch::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
+{
+  if (model==blinkTimer) {
+    showInvert=!showInvert;
+    Redraw();
+  }
+
+  Control::Resync(model,msg);
+}
+
