@@ -33,11 +33,14 @@ private:
   Lum::OS::FontRef      font;
   std::wstring          text;
   Lum::Model::ActionRef clickAction;
+  Lum::Model::ActionRef blinkTimer;
   Lum::OS::ColorRef     alarmColor;
   bool                  alarm;
+  bool                  showInvert;
 
 public:
   StopWatch();
+  ~StopWatch();
 
   Lum::Model::Action* GetClickAction() const;
 
@@ -52,6 +55,8 @@ public:
   void Draw(int x, int y, size_t w, size_t h);
 
   bool HandleMouseEvent(const Lum::OS::MouseEvent& event);
+
+  void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg);
 };
 
 #endif
